@@ -220,11 +220,13 @@ static inline void i8253_cascade_ns_to_timer_2div(int i8253_osc_base,
  *
  * FMH
  */
+
+static const int i8254_control_reg = 3;
+
 static inline int i8254_load(unsigned long base_address,
 	unsigned int counter_number, unsigned int count, unsigned int mode)
 {
 	unsigned int byte;
-	static const int counter_control = 3;
 
 	if(counter_number > 2) return -1;
 	if(count > 0xffff) return -1;
@@ -234,7 +236,7 @@ static inline int i8254_load(unsigned long base_address,
 	byte = counter_number << 6;
 	byte |= 0x30;	// load low then high byte
 	byte |= (mode << 1);	// set counter mode
-	outb(byte, base_address + counter_control);
+	outb(byte, base_address + i8254_control_reg);
 	byte = count & 0xff;	// lsb of counter value
 	outb(byte, base_address + counter_number);
 	byte = (count >> 8) & 0xff;	// msb of counter value
@@ -243,11 +245,10 @@ static inline int i8254_load(unsigned long base_address,
 	return 0;
 }
 
-static inline int i8254_mm_load(unsigned long base_address,
+static inline int i8254_mm_load(void *base_address,
 	unsigned int counter_number, unsigned int count, unsigned int mode)
 {
 	unsigned int byte;
-	static const int counter_control = 3;
 
 	if(counter_number > 2) return -1;
 	if(count > 0xffff) return -1;
@@ -257,7 +258,7 @@ static inline int i8254_mm_load(unsigned long base_address,
 	byte = counter_number << 6;
 	byte |= 0x30;	// load low then high byte
 	byte |= (mode << 1);	// set counter mode
-	writeb(byte, base_address + counter_control);
+	writeb(byte, base_address + i8254_control_reg);
 	byte = count & 0xff;	// lsb of counter value
 	writeb(byte, base_address + counter_number);
 	byte = (count >> 8) & 0xff;	// msb of counter value
@@ -271,13 +272,12 @@ static inline int i8254_read(unsigned long base_address, unsigned int counter_nu
 {
 	unsigned int byte;
 	int ret;
-	static const int counter_control = 3;
 
 	if(counter_number > 2) return -1;
 
 	// latch counter
 	byte = counter_number << 6;
-	outb(byte, base_address + counter_control);
+	outb(byte, base_address + i8254_control_reg);
 
 	// read lsb
 	ret = inb(base_address + counter_number);
@@ -286,6 +286,107 @@ static inline int i8254_read(unsigned long base_address, unsigned int counter_nu
 
 	return ret;
 }
+
+static inline int i8254_mm_read(void *base_address, unsigned int counter_number)
+{
+	unsigned int byte;
+	int ret;
+	static const int counter_control = 3;
+
+	if(counter_number > 2) return -1;
+
+	// latch counter
+	byte = counter_number << 6;
+	writeb(byte, base_address + counter_control);
+
+	// read lsb
+	ret = readb(base_address + counter_number);
+	// read msb
+	ret += readb(base_address + counter_number) << 8;
+
+	return ret;
+}
+
+/* Loads 16 bit initial counter value, should work for 8253 also. */
+static inline void i8254_write(unsigned long base_address,
+	unsigned int counter_number, unsigned int count)
+{
+	unsigned int byte;
+
+	if(counter_number > 2) return;
+
+	byte = count & 0xff;	// lsb of counter value
+	outb(byte, base_address + counter_number);
+	byte = (count >> 8) & 0xff;	// msb of counter value
+	outb(byte, base_address + counter_number);
+}
+
+static inline void i8254_mm_write(void *base_address,
+	unsigned int counter_number, unsigned int count)
+{
+	unsigned int byte;
+
+	if(counter_number > 2) return;
+
+	byte = count & 0xff;	// lsb of counter value
+	writeb(byte, base_address + counter_number);
+	byte = (count >> 8) & 0xff;	// msb of counter value
+	writeb(byte, base_address + counter_number);
+}
+
+/* Set counter mode, should work for 8253 also.
+ * Note: the 'mode' value is different to that for i8254_load() and comes
+ * from the INSN_CONFIG_8254_SET_MODE command:
+ *   I8254_MODE0, I8254_MODE1, ..., I8254_MODE5
+ * OR'ed with:
+ *   I8254_BCD, I8254_BINARY
+ */
+static inline int i8254_set_mode(unsigned long base_address,
+	unsigned int counter_number, unsigned int mode)
+{
+	unsigned int byte;
+	static const int counter_control = 3;
+
+	if(counter_number > 2) return -1;
+	if(mode > (I8254_MODE5 | I8254_BINARY)) return -1;
+
+	byte = counter_number << 6;
+	byte |= 0x30;	// load low then high byte
+	byte |= mode;	// set counter mode and BCD|binary
+	outb(byte, base_address + counter_control);
+
+	return 0;
+}
+
+static inline int i8254_mm_set_mode(void *base_address,
+	unsigned int counter_number, unsigned int mode)
+{
+	unsigned int byte;
+	static const int counter_control = 3;
+
+	if(counter_number > 2) return -1;
+	if(mode > (I8254_MODE5 | I8254_BINARY)) return -1;
+
+	byte = counter_number << 6;
+	byte |= 0x30;	// load low then high byte
+	byte |= mode;	// set counter mode and BCD|binary
+	writeb(byte, base_address + counter_control);
+
+	return 0;
+}
+
+static inline int i8254_status(unsigned long base_address, int counter_number)
+{
+	outb(0xE0 | (2 << counter_number), base_address + i8254_control_reg);
+	return inb(base_address + counter_number);
+}
+
+static inline int i8254_mm_status(void *base_address, int counter_number)
+{
+	writeb(0xE0 | (2 << counter_number), base_address + i8254_control_reg);
+	return readb(base_address + counter_number);
+}
+
 #endif
 
 #endif
