@@ -162,6 +162,7 @@ static int das08jr_di_rbits(comedi_device *dev,comedi_subdevice *s,comedi_insn *
 static int das08jr_do_wbits(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data);
 static int das08jr_ao_winsn(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data);
 static int das08ao_ao_winsn(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data);
+static void i8254_set_mode_low(unsigned int base, int channel, unsigned int mode);
 
 static comedi_lrange range_das08_pgl = { 9, {
 	BIP_RANGE(10),
@@ -718,19 +719,13 @@ static void i8254_write_channel(struct i8254_struct *st, int channel, unsigned i
         i8254_write_channel_low(st->iobase,chan,value);
 }
 
-#define I8254_CH0_LM  0x30
-#define I8254_CH1_LM  0x60
-#define I8254_CH2_LM  0x80
-
 static void i8254_initialize(struct i8254_struct *st)
 {
-        unsigned int port=st->iobase+I8254_CTRL;
-        outb(I8254_CH0_LM | st->mode[0],port);
-        outb(I8254_CH1_LM | st->mode[1],port);
-        outb(I8254_CH2_LM | st->mode[2],port);
+	int i;
+	for(i = 0 ; i < 3; ++i)
+		i8254_set_mode_low(st->iobase, i, st->mode[i]);
 }
 
-
 static void i8254_set_mode_low(unsigned int base, int channel, unsigned int mode)
 {
         outb((channel<<6) | 0x30 | (mode & 0x0F),base+I8254_CTRL);
@@ -815,15 +810,14 @@ int das08_common_attach(comedi_device *dev, unsigned long iobase )
 	comedi_subdevice *s;
 	int ret;
 
-	// allocate ioports for non-pcmcia boards
-	if(thisboard->bustype != pcmcia)
+	// allocate ioports for non-pcmcia, non-pci boards
+	if((thisboard->bustype != pcmcia) && (thisboard->bustype != pci))
 	{
 		printk(" iobase 0x%lx\n", iobase);
-		if(check_region(iobase, thisboard->iosize)<0){
+		if(!request_region(iobase, thisboard->iosize,"das08")){
 			printk(" I/O port conflict\n");
 			return -EIO;
 		}
-		request_region(iobase, thisboard->iosize,"das08");
 	}
 	dev->iobase = iobase;
 
@@ -962,18 +956,20 @@ static int das08_attach(comedi_device *dev,comedi_devconfig *it)
 			return -EIO;
 		}
 		devpriv->pdev = pdev;
-		// read base addresses
-		if(pci_enable_device(pdev))
+		// enable PCI device
+		if(pci_enable_device(pdev)){
+			printk(" Error enabling PCI device\n");
 			return -EIO;
-		pci_iobase = pci_resource_start(pdev, 1);
-		iobase = pci_resource_start(pdev, 2);
-		printk("pcibase 0x%lx ", pci_iobase);
-		// reserve io ports for 9052 pci chip
-		if(check_region(pci_iobase,PCIDAS08_SIZE)<0){
+		}
+		// reserve I/O spaces
+		if(pci_request_regions(pdev, "das08")){
 			printk(" I/O port conflict\n");
 			return -EIO;
 		}
-		request_region(pci_iobase,PCIDAS08_SIZE,"das08");
+		// read base addresses
+		pci_iobase = pci_resource_start(pdev, 1);
+		iobase = pci_resource_start(pdev, 2);
+		printk("pcibase 0x%lx  iobase 0x%lx\n", pci_iobase, iobase);
 		devpriv->pci_iobase = pci_iobase;
 #if 0
 /* We could enable to pci-das08's interrupt here to make it possible
@@ -1001,18 +997,20 @@ int das08_common_detach(comedi_device *dev)
 	if(dev->subdevices)
 		subdev_8255_cleanup(dev,dev->subdevices+4);
 
-	// deallocate ioports for non-pcmcia boards
-	if(thisboard->bustype != pcmcia)
+	// deallocate ioports for non-pcmcia, non-pci boards
+	if((thisboard->bustype != pcmcia) && (thisboard->bustype != pci))
 	{
 		if(dev->iobase)
 			release_region(dev->iobase, thisboard->iosize);
 	}
 
 	if(devpriv){
-		if(devpriv->pci_iobase){
-			release_region(devpriv->pci_iobase, PCIDAS08_SIZE);
-		}
 		if(devpriv->pdev){
+			if(devpriv->pci_iobase)
+			{
+				pci_release_regions(devpriv->pdev);
+				pci_disable_device(devpriv->pdev);
+			}
 			pci_dev_put(devpriv->pdev);
 		}
 	}
