@@ -123,8 +123,10 @@ static comedi_driver driver_dio24={
 static int dio24_attach(comedi_device *dev, comedi_devconfig *it)
 {
 	comedi_subdevice *s;
-	int iobase = 0;
-	int irq = 0;
+	unsigned long iobase = 0;
+#ifdef incomplete
+	unsigned int irq = 0;
+#endif
 	dev_link_t *link;
 
 	/* allocate and initialize dev->private */
@@ -138,18 +140,22 @@ static int dio24_attach(comedi_device *dev, comedi_devconfig *it)
 			link = pcmcia_dev_list; /* XXX hack */
 			if(!link) return -EIO;
 			iobase = link->io.BasePort1;
+#ifdef incomplete
 			irq = link->irq.AssignedIRQ;
+#endif
 			break;
 		default:
 			printk("bug! couldn't determine board type\n");
 			return -EINVAL;
 			break;
 	}
-	printk("comedi%d: ni_daq_dio24: %s, io 0x%x", dev->minor, thisboard->name, iobase);
+	printk("comedi%d: ni_daq_dio24: %s, io 0x%lx", dev->minor, thisboard->name, iobase);
+#ifdef incomplete
 	if(irq)
 	{
-		printk(", irq %i", irq);
+		printk(", irq %u", irq);
 	}
+#endif
 
 	printk("\n");
 
@@ -161,13 +167,10 @@ static int dio24_attach(comedi_device *dev, comedi_devconfig *it)
 
 	dev->iobase = iobase;
 
+#ifdef incomplete
 	/* grab our IRQ */
-	if(irq < 0)
-	{
-		printk("irq out of range\n");
-		return -EINVAL;
-	}
 	dev->irq = irq;
+#endif
 
 	dev->board_name = thisboard->name;
 
