@@ -912,7 +912,7 @@ static ni_board ni_boards[]={
 		adbits:         18,
 		ai_fifo_depth:  2047,
 		.gainlkup = ai_gain_628x,
-		ai_speed:	2000,
+		ai_speed:	1600,
 		n_aochan:       0,
 		aobits:         0,
 		ao_fifo_depth:  8191,
@@ -927,7 +927,7 @@ static ni_board ni_boards[]={
 		adbits:         18,
 		ai_fifo_depth:  2047,
 		.gainlkup = ai_gain_628x,
-		ai_speed:	800,
+		ai_speed:	1600,
 		n_aochan:       2,
 		aobits:         16,
 		ao_fifo_depth:  8191,
@@ -944,7 +944,7 @@ static ni_board ni_boards[]={
 		adbits:         18,
 		ai_fifo_depth:  2047,
 		.gainlkup = ai_gain_628x,
-		ai_speed:	2000,
+		ai_speed:	1600,
 		n_aochan:       0,
 		aobits:         0,
 		ao_fifo_depth:  0,
@@ -959,7 +959,7 @@ static ni_board ni_boards[]={
 		adbits:         18,
 		ai_fifo_depth:  2047,
 		.gainlkup = ai_gain_628x,
-		ai_speed:	800,
+		ai_speed:	1600,
 		n_aochan:       4,
 		aobits:         16,
 		ao_fifo_depth:  8191,
@@ -1365,7 +1365,7 @@ static int pcimio_attach(comedi_device *dev,comedi_devconfig *it)
 	if(dev->irq==0){
 		printk(" unknown irq (bad)\n");
 	}else{
-		printk(" ( irq = %d )",dev->irq);
+		printk(" ( irq = %u )",dev->irq);
 		if( (ret=comedi_request_irq(dev->irq,ni_E_interrupt,NI_E_IRQ_FLAGS,"ni_pcimio",dev))<0 ){
 			printk(" irq not available\n");
 			dev->irq=0;
