@@ -65,10 +65,10 @@ static int pcm3730_di_insn_bits(comedi_device *dev,comedi_subdevice *s,
 static int pcm3730_attach(comedi_device *dev,comedi_devconfig *it)
 {
 	comedi_subdevice *s;
-	int iobase;
+	unsigned long iobase;
 
 	iobase=it->options[0];
-	printk("comedi%d: pcm3730: 0x%04x ",dev->minor,iobase);
+	printk("comedi%d: pcm3730: 0x%04lx ",dev->minor,iobase);
 	if(!request_region(iobase,PCM3730_SIZE,"pcm3730")){
 		printk("I/O port conflict\n");
 		return -EIO;
