@@ -1,4 +1,4 @@
-#define DRIVER_VERSION "v1.00pre10"
+#define DRIVER_VERSION "v1.00pre12"
 #define DRIVER_AUTHOR "Bernd Porr, BerndPorr@f2s.com"
 #define DRIVER_DESC "Stirling/ITL USB-DUX -- Bernd.Porr@f2s.com"
 /*
@@ -25,7 +25,7 @@ Driver: usbdux.c
 Description: University of Stirling USB DAQ & INCITE Technology Limited
 Devices: [ITL] USB-DUX (usbdux.o)
 Author: Bernd Porr <BerndPorr@f2s.com>
-Updated: 04 Jan 2005
+Updated: 23 May 2005
 Status: Stable
 Configuration options:
   You have to upload firmware with the -i option. The
@@ -81,13 +81,6 @@ sampling rate. If you sample two channels you get 4kHz and so on.
 // generates loads of debug info
 // #define NOISY_DUX_DEBUGBUG
 
-// generates moderate amount of debug info
-#define CONFIG_COMEDI_DEBUG
-
-// uncomment this if you don't want to have debug infos from CVS versions
-#undef CONFIG_COMEDI_DEBUG
-
-
 #include <linux/kernel.h>
 #include <linux/module.h>
 #include <linux/init.h>
@@ -104,7 +97,7 @@ sampling rate. If you sample two channels you get 4kHz and so on.
 #define BOARDNAME "usbdux"
 
 // timeout for the USB-transfer
-#define EZTIMEOUT 3
+#define EZTIMEOUT 30
 
 // constants for "firmware" upload and download
 #define USBDUXSUB_FIRMWARE 0xA0
@@ -299,13 +292,16 @@ static DECLARE_MUTEX (start_stop_sem);
 // Stops the data acquision
 // It should be safe to call this function from any context
 static int usbduxsub_unlink_InURBs(usbduxsub_t* usbduxsub_tmp) {
-	int i,j=0;
+	int i=0;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,8)
+	int j=0;
+#endif
 	int err=0;
 
 	if (usbduxsub_tmp && usbduxsub_tmp->urbIn) {
 		for (i=0; i < usbduxsub_tmp->numOfInBuffers; i++) {
 			if (usbduxsub_tmp->urbIn[i]) {
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,10)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,8)
 				j=usb_unlink_urb(usbduxsub_tmp->urbIn[i]);
                                 if (j<0) {
                                         err=j;
@@ -316,10 +312,9 @@ static int usbduxsub_unlink_InURBs(usbduxsub_t* usbduxsub_tmp) {
                                 usb_kill_urb(usbduxsub_tmp->urbIn[i]);
 #endif
 			}
-#ifdef CONFIG_COMEDI_DEBUG
-			printk("comedi: usbdux: unlinked InURB %d: res=%d\n",
-			       i,
-			       j);
+#ifdef NOISY_DUX_DEBUGBUG
+			printk("comedi: usbdux: unlinked InURB %d, err=%d\n",
+			       i,err);
 #endif
 		}
 	}
@@ -341,7 +336,7 @@ static int usbdux_ai_stop(usbduxsub_t* this_usbduxsub,
 		return -EFAULT;
 	}
 
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi: usbdux_ai_stop\n");
 #endif
 
@@ -367,7 +362,7 @@ static int usbdux_ai_cancel(comedi_device *dev,
 	int res=0;
 
 	// force unlink of all urbs
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi: usbdux_ai_cancel\n");
 #endif
 	this_usbduxsub=dev->private;
@@ -565,13 +560,17 @@ static void usbduxsub_ai_IsocIrq(struct urb *urb, struct pt_regs *regs)
 
 
 static int usbduxsub_unlink_OutURBs(usbduxsub_t* usbduxsub_tmp) {
-	int i,j=0;
+	int i=0;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,8)
+	int j=0;
+#endif
+
 	int err=0;
 
 	if (usbduxsub_tmp && usbduxsub_tmp->urbOut) {
 		for (i=0; i < usbduxsub_tmp->numOfOutBuffers; i++) {
 			if (usbduxsub_tmp->urbOut[i]) {
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,10)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,8)
 				j=usb_unlink_urb(usbduxsub_tmp->urbOut[i]);
                                 if (j<err) {
                                         err=j;
@@ -580,8 +579,9 @@ static int usbduxsub_unlink_OutURBs(usbduxsub_t* usbduxsub_tmp) {
                                 usb_kill_urb(usbduxsub_tmp->urbOut[i]);
 #endif
 			}
-#ifdef CONFIG_COMEDI_DEBUG
-			printk("comedi: usbdux: unlinked OutURB %d: res=%d\n",i,j);
+#ifdef NOISY_DUX_DEBUGBUG
+			printk("comedi: usbdux: unlinked OutURB %d: res=%d\n",
+			       i,err);
 #endif
 		}
 	}
@@ -600,13 +600,13 @@ static int usbdux_ao_stop(usbduxsub_t* this_usbduxsub,
 	int ret=0;
 
 	if (!this_usbduxsub) {
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 		printk("comedi?: usbdux_ao_stop: this_usbduxsub=NULL!\n");
 #endif
 		return -EFAULT;
 	}
 
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi: usbdux_ao_cancel\n");
 #endif
 	if (do_unlink) {
@@ -829,7 +829,7 @@ static int usbduxsub_start(usbduxsub_t* usbduxsub) {
 	if (usbduxsub->probed) {
 		// 7f92 to zero
 		local_transfer_buffer[0]=0; 
-		errcode=usb_control_msg
+		errcode=USB_CONTROL_MSG
 			(usbduxsub->usbdev,
 			 // create a pipe for a control transfer
 			 usb_sndctrlpipe(usbduxsub->usbdev,0),
@@ -866,7 +866,7 @@ static int usbduxsub_stop(usbduxsub_t* usbduxsub) {
 	if (usbduxsub->probed) {
 		// 7f92 to one
 		local_transfer_buffer[0]=1; 
-		errcode=usb_control_msg
+		errcode=USB_CONTROL_MSG
 			(usbduxsub->usbdev,
 			 usb_sndctrlpipe(usbduxsub->usbdev,0),
 			 // bRequest, "Firmware"
@@ -909,7 +909,7 @@ static int usbduxsub_upload(usbduxsub_t* usbduxsub,
 		       startAddr,
 		       local_transfer_buffer[0]);
 #endif
-		errcode=usb_control_msg
+		errcode=USB_CONTROL_MSG
 			(usbduxsub->usbdev,
 			 usb_sndctrlpipe(usbduxsub->usbdev, 0),
 			 // brequest, firmware
@@ -927,7 +927,7 @@ static int usbduxsub_upload(usbduxsub_t* usbduxsub,
 			 // timeout
 			 EZTIMEOUT
 			 );
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 		printk("comedi_: usbdux: result=%d\n",errcode);
 #endif
 		if (errcode<0) {
@@ -993,7 +993,7 @@ int usbduxsub_submit_InURBs(usbduxsub_t* usbduxsub) {
 		usbduxsub->urbIn[i]->dev = usbduxsub->usbdev;
 		usbduxsub->urbIn[i]->status = 0;
 		usbduxsub->urbIn[i]->transfer_flags = URB_ISO_ASAP;
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 		printk("comedi%d: usbdux: submitting in-urb[%d]: %p,%p intv=%d\n",
 		       usbduxsub->comedidev->minor,
 		       i,
@@ -1023,7 +1023,7 @@ int usbduxsub_submit_OutURBs(usbduxsub_t* usbduxsub) {
 		return -EFAULT;
 	}
 	for (i=0; i < usbduxsub->numOfOutBuffers; i++) {
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 		printk("comedi_: usbdux: submitting out-urb[%d]\n",i);
 #endif
 		// in case of a resubmission after an unlink...
@@ -1052,12 +1052,13 @@ static int usbdux_ai_cmdtest(comedi_device *dev,
 			     comedi_cmd *cmd)
 {
 	int err=0,tmp,i;
+	unsigned int tmpTimer;	
 	usbduxsub_t* this_usbduxsub=dev->private;
 	if (!(this_usbduxsub->probed)) {
 		return -ENODEV;
 	}
 
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi%d: usbdux_ai_cmdtest\n",dev->minor);
 #endif
 	/* make sure triggers are valid */
@@ -1130,12 +1131,24 @@ static int usbdux_ai_cmdtest(comedi_device *dev,
 				cmd->scan_begin_arg=1000000/8*i;
 				err++;
 			}
+			// now calc the real sampling rate with all the rounding errors
+			tmpTimer = ((unsigned int)(cmd->scan_begin_arg/125000))*125000;
+			if (cmd->scan_begin_arg != tmpTimer) {
+				cmd->scan_begin_arg = tmpTimer;
+				err++;
+			}
 		} else { // full speed
 			// 1kHz scans every USB frame
 			if(cmd->scan_begin_arg<1000000){
 				cmd->scan_begin_arg=1000000;
 				err++;
 			}
+			// calc the real sampling rate with the rounding errors
+			tmpTimer = ((unsigned int)(cmd->scan_begin_arg/1000000))*1000000;
+			if (cmd->scan_begin_arg != tmpTimer) {
+				cmd->scan_begin_arg = tmpTimer;
+				err++;
+			}
 		}
 	}
 	// the same argument
@@ -1196,7 +1209,7 @@ static int send_dux_commands(usbduxsub_t* this_usbduxsub,int cmd_type) {
 	}
 	printk("\n");
 #endif
-	result = usb_bulk_msg(this_usbduxsub->usbdev,
+	result = USB_BULK_MSG(this_usbduxsub->usbdev,
 			      usb_sndbulkpipe(this_usbduxsub->usbdev,
 					      COMMAND_OUT_EP),
 			      this_usbduxsub->dux_commands,
@@ -1221,7 +1234,7 @@ static int receive_dux_commands(usbduxsub_t* this_usbduxsub,int command) {
 	int i;
 	
 	for(i=0;i<RETRIES;i++) {
-		result = usb_bulk_msg(this_usbduxsub->usbdev,
+		result = USB_BULK_MSG(this_usbduxsub->usbdev,
 				      usb_rcvbulkpipe(this_usbduxsub->usbdev,
 						      COMMAND_IN_EP),
 				      this_usbduxsub->insnBuffer,
@@ -1269,7 +1282,7 @@ static int usbdux_ai_inttrig(comedi_device *dev,
 		return -ENODEV;
 	}
 
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi%d: usbdux_ai_inttrig\n",dev->minor);
 #endif
 
@@ -1313,7 +1326,7 @@ static int usbdux_ai_cmd(comedi_device *dev, comedi_subdevice *s)
 	usbduxsub_t* this_usbduxsub=dev->private;
 	int result;
 
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi%d: usbdux_ai_cmd\n",dev->minor);
 #endif
 	if (!this_usbduxsub) {
@@ -1349,7 +1362,7 @@ static int usbdux_ai_cmd(comedi_device *dev, comedi_subdevice *s)
 	}
 
 
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi %d: sending commands to the usb device: ",
 	       dev->minor);
 	printk("size=%u\n",
@@ -1627,7 +1640,7 @@ static int usbdux_ao_cmdtest(comedi_device *dev,
 	if (!(this_usbduxsub->probed)) {
 		return -ENODEV;
 	}
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi%d: usbdux_ao_cmdtest\n",dev->minor);
 #endif
 	/* make sure triggers are valid */
@@ -1735,7 +1748,7 @@ static int usbdux_ao_cmdtest(comedi_device *dev,
 		}
 	}
 
-#ifdef CONFIG_COMEDI_DEBUG 
+#ifdef NOISY_DUX_DEBUGBUG 
 	printk("comedi%d: err=%d, scan_begin_src=%d, scan_begin_arg=%d, convert_src=%d, convert_arg=%d\n", 
 	       dev->minor, 
 	       err,
@@ -1768,7 +1781,7 @@ static int usbdux_ao_cmd(comedi_device *dev, comedi_subdevice *s)
 		up(&this_usbduxsub->sem);
 		return -ENODEV;
 	}
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 	printk("comedi%d: usbdux_ao_cmd\n",dev->minor);
 #endif
 
@@ -1782,7 +1795,7 @@ static int usbdux_ao_cmd(comedi_device *dev, comedi_subdevice *s)
 			break;
 		}
 		this_usbduxsub->dac_commands[i]=(chan<<6);
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
 		printk("comedi%d: dac command for ch %d is %x\n",
 		       dev->minor,
 		       i,
@@ -1801,7 +1814,7 @@ static int usbdux_ao_cmd(comedi_device *dev, comedi_subdevice *s)
 		// 1ms
 		// timing of the scan: we get all channels at once
 		this_usbduxsub->ao_timer = cmd->scan_begin_arg/1000000;
-#ifdef CONFIG_COMEDI_DEBUG
+#ifdef NOISY_DUX_DEBUGBUG
                 printk("comedi%d: usbdux: scan_begin_src=%d, scan_begin_arg=%d, convert_src=%d, convert_arg=%d\n",
                        dev->minor,
 		       cmd->scan_begin_src,
@@ -2056,6 +2069,9 @@ static void tidy_up(usbduxsub_t* usbduxsub_tmp) {
 				usbduxsub_tmp->urbIn[i]->transfer_buffer=NULL;
 			}
 			if (usbduxsub_tmp->urbIn[i]) {
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,8)
+				usb_kill_urb(usbduxsub_tmp->urbIn[i]);
+#endif
 				usb_free_urb (usbduxsub_tmp->urbIn[i]);
 				usbduxsub_tmp->urbIn[i]=NULL;
 			}
@@ -2074,6 +2090,9 @@ static void tidy_up(usbduxsub_t* usbduxsub_tmp) {
 				usbduxsub_tmp->urbOut[i]->transfer_buffer=NULL;
 			}
 			if (usbduxsub_tmp->urbOut[i]) {
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,8)
+				usb_kill_urb(usbduxsub_tmp->urbOut[i]);
+#endif
 				usb_free_urb (usbduxsub_tmp->urbOut[i]);
 				usbduxsub_tmp->urbOut[i]=NULL;
 			}
@@ -2464,7 +2483,7 @@ static int usbduxsub_probe(struct usb_interface *uinterf,
 	// we've reached the bottom of the function
 	usbduxsub[index].probed=1;
 	up(&start_stop_sem);	
-	printk("comedi_: usbdux%d has been successfully initialized.\n",index);
+	printk("comedi_: usbdux%d has been successfully initialised.\n",index);
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)
 	return (void*)(&usbduxsub[index]);
 #else
@@ -2541,9 +2560,9 @@ static int usbdux_attach(comedi_device * dev, comedi_devconfig * it)
 
 	// trying to upload the firmware into the chip
 	if(comedi_aux_data(it->options, 0) && 
-	   it->options[COMEDI_DEVCONF_AUX_DATA_LENGTH]){
-		read_firmware(usbduxsub,
-			comedi_aux_data(it->options, 0),
+	        it->options[COMEDI_DEVCONF_AUX_DATA_LENGTH]){
+	        read_firmware(usbduxsub+index,
+			      comedi_aux_data(it->options, 0),
 			      it->options[COMEDI_DEVCONF_AUX_DATA_LENGTH]);
 	} 
 
@@ -2647,7 +2666,7 @@ static int usbdux_attach(comedi_device * dev, comedi_devconfig * it)
 
 	up(&start_stop_sem);
 
-	printk("comedi%d: successfully attached to usbdux.\n",
+	printk("comedi%d: attached to usbdux.\n",
 	       dev->minor);
 
 	return 0;
@@ -2744,7 +2763,7 @@ MODULE_DEVICE_TABLE (usb, usbduxsub_table);
 
 // The usbduxsub-driver
 static struct usb_driver usbduxsub_driver = {
-#if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,19)
+#ifdef COMEDI_HAVE_USB_DRIVER_OWNER
         owner:          THIS_MODULE,
 #endif
 	name:		BOARDNAME,
